@@ -13,16 +13,20 @@ import numpy as np
 
 import astropy.units as u
 from astropy.coordinates import Latitude, Longitude
+from astropy.io import fits
 from astropy.time import TimeDelta
 from sunpy.coordinates import sun
-from sunpy.io.fits import fits
 from sunpy.time import TimeRange, parse_time
 from sunpy.time.time import _variables_for_parse_time_docstring
 from sunpy.util.decorators import add_common_docstring
 
-__all__ = ['download_weekly_pointing_file', 'get_detector_sun_angles_for_time',
-           'get_detector_sun_angles_for_date', 'plot_detector_sun_angles',
-           'met_to_utc']
+__all__ = [
+    "download_weekly_pointing_file",
+    "get_detector_sun_angles_for_time",
+    "get_detector_sun_angles_for_date",
+    "plot_detector_sun_angles",
+    "met_to_utc",
+]
 
 
 @add_common_docstring(**_variables_for_parse_time_docstring())
@@ -50,13 +54,13 @@ def download_weekly_pointing_file(date):
     # use a temp directory to hold the file
     tmp_dir = tempfile.mkdtemp()
     # use Fermi data server to access weekly LAT pointing file.
-    base_url = 'https://heasarc.gsfc.nasa.gov/FTP/fermi/data/lat/weekly/spacecraft/'
-    fbasename = 'lat_spacecraft_weekly_w'
+    base_url = "https://heasarc.gsfc.nasa.gov/FTP/fermi/data/lat/weekly/spacecraft/"
+    fbasename = "lat_spacecraft_weekly_w"
 
     # find out which file to get based on date
     # earliest full file in the FERMI server is for mission week 10,
     # beginning 2008 August 7.
-    weekly_file_start = parse_time('2008-08-07')
+    weekly_file_start = parse_time("2008-08-07")
     base_week = 10
 
     # find out which mission week corresponds to date
@@ -64,22 +68,23 @@ def download_weekly_pointing_file(date):
     weekdiff = time_diff.to(u.day).value // 7
     week = weekdiff + base_week
     # weekstr = ('%03.0f' % week)
-    weekstr = f'{week:03.0f}'
+    weekstr = f"{week:03.0f}"
 
     # construct the full url for the weekly pointing file
-    full_fname = fbasename + weekstr + '_p202_v001.fits'
+    full_fname = fbasename + weekstr + "_p310_v001.fits"
     pointing_file_url = base_url + full_fname
 
     # try to download the file
     try:
-        urllib.request.urlopen(pointing_file_url)
-        exists = True
+        # Use a context manager to avoid leaving a connection open
+        with urllib.request.urlopen(pointing_file_url) as _:
+            exists = True
     except urllib.error.HTTPError:
         exists = False
 
     # if no matches at all were found, then the pointing file doesn't exist
     if not exists:
-        raise ValueError('No Fermi pointing files found for given date!')
+        raise ValueError("No Fermi pointing files found for given date!")
 
     # download the file
     destination = os.path.join(tmp_dir, full_fname)
@@ -120,14 +125,15 @@ def get_detector_sun_angles_for_time(time, file):
 
     # this gets the sun position with RA in hours in decimal format (e.g. 4.3).
     # DEC is already in degrees
-    sunpos_ra_not_in_deg = [sun.apparent_rightascension(time),
-                            sun.apparent_declination(time)]
+    sunpos_ra_not_in_deg = [
+        sun.apparent_rightascension(time),
+        sun.apparent_declination(time),
+    ]
     # now Sun position with RA in degrees
-    sun_pos = [sunpos_ra_not_in_deg[0].to('deg'), sunpos_ra_not_in_deg[1]]
+    sun_pos = [sunpos_ra_not_in_deg[0].to("deg"), sunpos_ra_not_in_deg[1]]
     # sun_pos = [(sunpos_ra_not_in_deg[0] / 24) * 360., sunpos_ra_not_in_deg[1]]
     # now get the angle between each detector and the Sun
-    detector_to_sun_angles = (get_detector_separation_angles(detector_radecs,
-                                                             sun_pos))
+    detector_to_sun_angles = get_detector_separation_angles(detector_radecs, sun_pos)
 
     return detector_to_sun_angles
 
@@ -154,7 +160,7 @@ def get_detector_sun_angles_for_date(date, file):
     """
 
     date = parse_time(date)
-    tran = TimeRange(date, date + TimeDelta(1*u.day))
+    tran = TimeRange(date, date + TimeDelta(1 * u.day))
     scx, scz, times = get_scx_scz_in_timerange(tran, file)
 
     # retrieve the detector angle information in spacecraft coordinates
@@ -164,31 +170,46 @@ def get_detector_sun_angles_for_date(date, file):
     # get the detector vs Sun angles for each t and store in a list of
     # dictionaries.
     for i in range(len(scx)):
-        detector_radecs = nai_detector_radecs(detectors, scx[i], scz[i],
-                                              times[i])
+        detector_radecs = nai_detector_radecs(detectors, scx[i], scz[i], times[i])
 
         # this gets the sun position with RA in hours in decimal format
         # (e.g. 4.3). DEC is already in degrees
-        sunpos_ra_not_in_deg = [sun.apparent_rightascension(times[i]),
-                                sun.apparent_declination(times[i])]
+        sunpos_ra_not_in_deg = [
+            sun.apparent_rightascension(times[i]),
+            sun.apparent_declination(times[i]),
+        ]
         # now Sun position with RA in degrees
-        sun_pos = [sunpos_ra_not_in_deg[0].to('deg'), sunpos_ra_not_in_deg[1]]
+        sun_pos = [sunpos_ra_not_in_deg[0].to("deg"), sunpos_ra_not_in_deg[1]]
         # now get the angle between each detector and the Sun
         detector_to_sun_angles.append(
-            get_detector_separation_angles(detector_radecs, sun_pos))
+            get_detector_separation_angles(detector_radecs, sun_pos)
+        )
 
     # slice the list of dictionaries to get the angles for each detector in a
     # list form
     angles = OrderedDict()
-    key_list = ['n0', 'n1', 'n2', 'n3', 'n4', 'n5', 'n6', 'n7', 'n8', 'n9',
-                'n10', 'n11', 'time']
+    key_list = [
+        "n0",
+        "n1",
+        "n2",
+        "n3",
+        "n4",
+        "n5",
+        "n6",
+        "n7",
+        "n8",
+        "n9",
+        "n10",
+        "n11",
+        "time",
+    ]
     for i in range(13):
-        if not key_list[i] == 'time':
-            angles[key_list[i]] = [item[key_list[i]].value
-                                   for item in detector_to_sun_angles] * u.deg
+        if not key_list[i] == "time":
+            angles[key_list[i]] = [
+                item[key_list[i]].value for item in detector_to_sun_angles
+            ] * u.deg
         else:
-            angles[key_list[i]] = [item[key_list[i]]
-                                   for item in detector_to_sun_angles]
+            angles[key_list[i]] = [item[key_list[i]] for item in detector_to_sun_angles]
 
     return angles
 
@@ -208,16 +229,18 @@ def plot_detector_sun_angles(angles):
     # make a plot showing the angles vs time
     figure = plt.figure(1)
     for n in angles.keys():
-        if not n == 'time':
+        if not n == "time":
             plt.plot(
-                angles['time'],
+                angles["time"],
                 angles[n].value,
-                label='{lab} ({val})'.format(
-                    lab=n, val=str(np.mean(angles[n].value))[0:5]))
+                label="{lab} ({val})".format(
+                    lab=n, val=str(np.mean(angles[n].value))[0:5]
+                ),
+            )
     plt.ylim(180, 0)
-    plt.ylabel('angle (degrees)')
-    plt.xlabel('Start time: ' + angles['time'][0].isoformat())
-    plt.title('Detector pointing angle from Sun')
+    plt.ylabel("angle (degrees)")
+    plt.xlabel("Start time: " + angles["time"][0].isoformat())
+    plt.title("Detector pointing angle from Sun")
     plt.legend(fontsize=10)
     figure.autofmt_xdate()
     plt.show()
@@ -248,14 +271,18 @@ def get_scx_scz_at_time(time, file):
     time = parse_time(time)
     hdulist = fits.open(file)
     timesinutc = []
-    for tim in hdulist[1].data['START']:
+    for tim in hdulist[1].data["START"]:
         timesinutc.append(met_to_utc(tim))
     ind = np.searchsorted(timesinutc, time)
 
-    scx_radec = (Longitude(hdulist[1].data['RA_SCX'][ind] * u.deg),
-                 Latitude(hdulist[1].data['DEC_SCX'][ind] * u.deg))
-    scz_radec = (Longitude(hdulist[1].data['RA_SCZ'][ind] * u.deg),
-                 Latitude(hdulist[1].data['DEC_SCZ'][ind] * u.deg))
+    scx_radec = (
+        Longitude(hdulist[1].data["RA_SCX"][ind] * u.deg),
+        Latitude(hdulist[1].data["DEC_SCX"][ind] * u.deg),
+    )
+    scz_radec = (
+        Longitude(hdulist[1].data["RA_SCZ"][ind] * u.deg),
+        Latitude(hdulist[1].data["DEC_SCZ"][ind] * u.deg),
+    )
 
     return scx_radec, scz_radec, timesinutc[ind]
 
@@ -282,7 +309,7 @@ def get_scx_scz_in_timerange(timerange, file):
 
     hdulist = fits.open(file)
     timesinutc = []
-    for tim in hdulist[1].data['START']:
+    for tim in hdulist[1].data["START"]:
         timesinutc.append(met_to_utc(tim))
 
     startind = np.searchsorted(timesinutc, timerange.start)
@@ -291,10 +318,18 @@ def get_scx_scz_in_timerange(timerange, file):
     scx_radec = []
     scz_radec = []
     for i in range(startind, endind):
-        scx_radec.append((Longitude(hdulist[1].data['RA_SCX'][i] * u.deg),
-                          Latitude(hdulist[1].data['DEC_SCX'][i] * u.deg)))
-        scz_radec.append((Longitude(hdulist[1].data['RA_SCZ'][i] * u.deg),
-                          Latitude(hdulist[1].data['DEC_SCZ'][i] * u.deg)))
+        scx_radec.append(
+            (
+                Longitude(hdulist[1].data["RA_SCX"][i] * u.deg),
+                Latitude(hdulist[1].data["DEC_SCX"][i] * u.deg),
+            )
+        )
+        scz_radec.append(
+            (
+                Longitude(hdulist[1].data["RA_SCZ"][i] * u.deg),
+                Latitude(hdulist[1].data["DEC_SCZ"][i] * u.deg),
+            )
+        )
     return scx_radec, scz_radec, timesinutc[startind:endind]
 
 
@@ -313,18 +348,20 @@ def nai_detector_angles():
     """
 
     # angles listed as [azimuth, zenith]
-    detectors = {'n0': [45.89 * u.deg, 20.58 * u.deg],
-                 'n1': [45.11 * u.deg, 45.31 * u.deg],
-                 'n2': [58.44 * u.deg, 90.21 * u.deg],
-                 'n3': [314.87 * u.deg, 45.24 * u.deg],
-                 'n4': [303.15 * u.deg, 90.27 * u.deg],
-                 'n5': [3.35 * u.deg, 89.79 * u.deg],
-                 'n6': [224.93 * u.deg, 20.43 * u.deg],
-                 'n7': [224.62 * u.deg, 46.18 * u.deg],
-                 'n8': [236.61 * u.deg, 89.97 * u.deg],
-                 'n9': [135.19 * u.deg, 45.55 * u.deg],
-                 'n10': [123.73 * u.deg, 90.42 * u.deg],
-                 'n11': [183.74 * u.deg, 90.32 * u.deg]}
+    detectors = {
+        "n0": [45.89 * u.deg, 20.58 * u.deg],
+        "n1": [45.11 * u.deg, 45.31 * u.deg],
+        "n2": [58.44 * u.deg, 90.21 * u.deg],
+        "n3": [314.87 * u.deg, 45.24 * u.deg],
+        "n4": [303.15 * u.deg, 90.27 * u.deg],
+        "n5": [3.35 * u.deg, 89.79 * u.deg],
+        "n6": [224.93 * u.deg, 20.43 * u.deg],
+        "n7": [224.62 * u.deg, 46.18 * u.deg],
+        "n8": [236.61 * u.deg, 89.97 * u.deg],
+        "n9": [135.19 * u.deg, 45.55 * u.deg],
+        "n10": [123.73 * u.deg, 90.42 * u.deg],
+        "n11": [183.74 * u.deg, 90.32 * u.deg],
+    }
 
     return detectors
 
@@ -362,15 +399,21 @@ def nai_detector_radecs(detectors, scx, scz, time):
         the given input time.
     """
 
-    scx_vector = (np.array(
-        [np.cos(scx[0].to('rad').value) * np.cos(scx[1].to('rad').value),
-         np.sin(scx[0].to('rad').value) * np.cos(scx[1].to('rad').value),
-         np.sin(scx[1].to('rad').value)]))
+    scx_vector = np.array(
+        [
+            np.cos(scx[0].to("rad").value) * np.cos(scx[1].to("rad").value),
+            np.sin(scx[0].to("rad").value) * np.cos(scx[1].to("rad").value),
+            np.sin(scx[1].to("rad").value),
+        ]
+    )
 
-    scz_vector = (np.array(
-        [np.cos(scz[0].to('rad').value) * np.cos(scz[1].to('rad').value),
-         np.sin(scz[0].to('rad').value) * np.cos(scz[1].to('rad').value),
-         np.sin(scz[1].to('rad').value)]))
+    scz_vector = np.array(
+        [
+            np.cos(scz[0].to("rad").value) * np.cos(scz[1].to("rad").value),
+            np.sin(scz[0].to("rad").value) * np.cos(scz[1].to("rad").value),
+            np.sin(scz[1].to("rad").value),
+        ]
+    )
 
     # For each detector, do the rotation depending on the detector zenith and
     # azimuth angles.
@@ -389,14 +432,13 @@ def nai_detector_radecs(detectors, scx, scz, time):
         vz_primed = rotate_vector(scz_vector, vy_primed, np.deg2rad(theta))
 
         # now we should be pointing at the new RA/DEC.
-        ra = Longitude(
-            np.degrees(np.arctan2(vz_primed[1], vz_primed[0])) * u.deg)
+        ra = Longitude(np.degrees(np.arctan2(vz_primed[1], vz_primed[0])) * u.deg)
         dec = Latitude(np.degrees(np.arcsin(vz_primed[2])) * u.deg)
 
         # save the RA/DEC in a dictionary
         detector_radecs[l] = [ra, dec]
 
-    detector_radecs['time'] = time
+    detector_radecs["time"] = time
     return detector_radecs
 
 
@@ -423,11 +465,12 @@ def rotate_vector(vector, axis, theta):
     b, c, d = -axis * np.sin(theta / 2)
 
     rot_matrix = np.array(
-        [[a * a + b * b - c * c - d * d, 2 * (b * c + a * d), 2 *
-          (b * d - a * c)], [2 * (b * c - a * d), a * a + c * c - b * b - d *
-                             d, 2 * (c * d + a * b)],
-         [2 * (b * d + a * c), 2 * (c * d - a * b), a * a + d * d - b * b - c *
-          c]])
+        [
+            [a * a + b * b - c * c - d * d, 2 * (b * c + a * d), 2 * (b * d - a * c)],
+            [2 * (b * c - a * d), a * a + c * c - b * b - d * d, 2 * (c * d + a * b)],
+            [2 * (b * d + a * c), 2 * (c * d - a * b), a * a + d * d - b * b - c * c],
+        ]
+    )
 
     return np.dot(rot_matrix, vector)
 
@@ -449,7 +492,7 @@ def get_detector_separation_angles(detector_radecs, sunpos):
     """
     angles = copy.deepcopy(detector_radecs)
     for l, d in detector_radecs.items():
-        if not l == 'time':
+        if not l == "time":
             angle = separation_angle(d, sunpos)
             angles[l] = angle
 
@@ -474,13 +517,15 @@ def separation_angle(radec1, radec2):
     """
 
     cosine_of_angle = (
-        (np.cos(((90 * u.deg) - radec1[1].to('degree')).to('rad')) *
-         np.cos((90 * u.deg - radec2[1].to('degree')).to('rad'))) +
-        (np.sin(((90 * u.deg) - radec1[1].to('degree')).to('rad')) *
-         np.sin(((90 * u.deg) - radec2[1].to('degree')).to('rad')) *
-         np.cos((radec1[0].to('degree') - radec2[0].to('degree')).to('rad'))))
+        np.cos(((90 * u.deg) - radec1[1].to("degree")).to("rad"))
+        * np.cos((90 * u.deg - radec2[1].to("degree")).to("rad"))
+    ) + (
+        np.sin(((90 * u.deg) - radec1[1].to("degree")).to("rad"))
+        * np.sin(((90 * u.deg) - radec2[1].to("degree")).to("rad"))
+        * np.cos((radec1[0].to("degree") - radec2[0].to("degree")).to("rad"))
+    )
 
-    angle = (np.arccos(cosine_of_angle)).to('degree')
+    angle = (np.arccos(cosine_of_angle)).to("degree")
 
     return angle
 
@@ -503,7 +548,7 @@ def met_to_utc(timeinsec):
     """
     # Times for GBM are in Mission Elapsed Time (MET).
     # The reference time for this is 2001-Jan-01 00:00.
-    met_ref_time = parse_time('2001-01-01 00:00')
+    met_ref_time = parse_time("2001-01-01 00:00")
 
     return met_ref_time + timeinsec * u.second
 
@@ -524,6 +569,6 @@ def utc_to_met(time_ut):
     `astropy.units.Quantity`
         The Fermi Mission Elapsed Time corresponding to the input UT
     """
-    met_ref_time = parse_time('2001-01-01 00:00')
+    met_ref_time = parse_time("2001-01-01 00:00")
 
     return (time_ut - met_ref_time).to(u.second)
