@@ -22,18 +22,20 @@ from sunpy.util.decorators import add_common_docstring
 LYTAF_REMOTE_PATH = "http://proba2.oma.be/lyra/data/lytaf/"
 
 
-__all__ = ['remove_lytaf_events_from_timeseries',
-           'get_lytaf_events',
-           'get_lytaf_event_types',
-           'split_series_using_lytaf',
-           '_prep_columns',
-           '_lytaf_event2string',
-           '_remove_lytaf_events']
+__all__ = [
+    "remove_lytaf_events_from_timeseries",
+    "get_lytaf_events",
+    "get_lytaf_event_types",
+    "split_series_using_lytaf",
+    "_prep_columns",
+    "_lytaf_event2string",
+    "_remove_lytaf_events",
+]
 
 
-def remove_lytaf_events_from_timeseries(ts, artifacts=None,
-                                        return_artifacts=False,
-                                        force_use_local_lytaf=False):
+def remove_lytaf_events_from_timeseries(
+    ts, artifacts=None, return_artifacts=False, force_use_local_lytaf=False
+):
     """
     Removes periods of LYRA artifacts defined in LYTAF from a TimeSeries.
 
@@ -87,7 +89,6 @@ def remove_lytaf_events_from_timeseries(ts, artifacts=None,
     Examples
     --------
     Remove LARs (Large Angle Rotations) from TimeSeries for 4-Dec-2014:
-
         >>> import sunpy.timeseries as ts
         >>> import sunpy.data.sample  # doctest: +REMOTE_DATA
         >>> from sunkit_instruments.lyra import remove_lytaf_events_from_timeseries
@@ -104,13 +105,15 @@ def remove_lytaf_events_from_timeseries(ts, artifacts=None,
     time, channels, artifact_status = _remove_lytaf_events(
         ts_ds.index,
         channels=[np.asanyarray(ts_ds[col]) for col in data_columns],
-        artifacts=artifacts, return_artifacts=True,
-        force_use_local_lytaf=force_use_local_lytaf)
-    # Create new copy copy of timeseries and replace data with
+        artifacts=artifacts,
+        return_artifacts=True,
+        force_use_local_lytaf=force_use_local_lytaf,
+    )
+    # Create new copy of timeseries and replace data with
     # artifact-free time series.
     data = pandas.DataFrame(
-        index=time, data={col: channels[i]
-                          for i, col in enumerate(data_columns)})
+        index=time, data={col: channels[i] for i, col in enumerate(data_columns)}
+    )
     ts_new = TimeSeries(data, ts.meta)
     if return_artifacts:
         return ts_new, artifact_status
@@ -118,9 +121,14 @@ def remove_lytaf_events_from_timeseries(ts, artifacts=None,
         return ts_new
 
 
-def _remove_lytaf_events(time, channels=None, artifacts=None,
-                         return_artifacts=False, filecolumns=None,
-                         force_use_local_lytaf=False):
+def _remove_lytaf_events(
+    time,
+    channels=None,
+    artifacts=None,
+    return_artifacts=False,
+    filecolumns=None,
+    force_use_local_lytaf=False,
+):
     """
     Removes periods of LYRA artifacts from a time series.
 
@@ -206,9 +214,10 @@ def _remove_lytaf_events(time, channels=None, artifacts=None,
         ...   time, channels=[channel_1, channel_2], artifacts=['LAR'])  # doctest: +SKIP
     """
     # Check inputs
-    if channels and type(channels) is not list:
-        raise TypeError("channels must be None or a list of numpy arrays "
-                        "of dtype 'float64'.")
+    if channels and not isinstance(channels, list):
+        raise TypeError(
+            f"channels must be None or a list of numpy arrays of dtype 'float64', not {type(channels)}"
+        )
     if not artifacts:
         raise ValueError("User has supplied no artifacts to remove.")
     if type(artifacts) is str:
@@ -225,7 +234,9 @@ def _remove_lytaf_events(time, channels=None, artifacts=None,
     clean_channels = copy.deepcopy(channels)
     artifacts_not_found = []
     # Get LYTAF file for given time range
-    lytaf = get_lytaf_events(time[0], time[-1], force_use_local_lytaf=force_use_local_lytaf)
+    lytaf = get_lytaf_events(
+        time[0], time[-1], force_use_local_lytaf=force_use_local_lytaf
+    )
 
     # Find events in lytaf which are to be removed from time series.
     artifact_indices = np.empty(0, dtype="int64")
@@ -252,8 +263,10 @@ def _remove_lytaf_events(time, channels=None, artifacts=None,
         bad_indices = np.empty(0, dtype="int64")
         all_indices = np.arange(len(time))
         for index in artifact_indices:
-            bad_period = np.logical_and(time >= lytaf["begin_time"][index].datetime,
-                                        time <= lytaf["end_time"][index].datetime)
+            bad_period = np.logical_and(
+                time >= lytaf["begin_time"][index].datetime,
+                time <= lytaf["end_time"][index].datetime,
+            )
             bad_indices = np.append(bad_indices, all_indices[bad_period])
         clean_time = np.delete(clean_time, bad_indices)
         if channels:
@@ -262,10 +275,12 @@ def _remove_lytaf_events(time, channels=None, artifacts=None,
     # If return_artifacts kwarg is True, return a list containing
     # information on what artifacts found, removed, etc.  See docstring.
     if return_artifacts:
-        artifact_status = {"lytaf": lytaf,
-                           "removed": lytaf[artifact_indices],
-                           "not_removed": np.delete(lytaf, artifact_indices),
-                           "not_found": artifacts_not_found}
+        artifact_status = {
+            "lytaf": lytaf,
+            "removed": lytaf[artifact_indices],
+            "not_removed": np.delete(lytaf, artifact_indices),
+            "not_found": artifacts_not_found,
+        }
 
     # Return values.
     if return_artifacts:
@@ -280,8 +295,13 @@ def _remove_lytaf_events(time, channels=None, artifacts=None,
             return clean_time, clean_channels
 
 
-def get_lytaf_events(start_time, end_time, combine_files=("lyra", "manual", "ppt", "science"),
-                     csvfile=None, force_use_local_lytaf=False):
+def get_lytaf_events(
+    start_time,
+    end_time,
+    combine_files=("lyra", "manual", "ppt", "science"),
+    csvfile=None,
+    force_use_local_lytaf=False,
+):
     """
     Extracts combined lytaf file for given time range.
 
@@ -342,26 +362,34 @@ def get_lytaf_events(start_time, end_time, combine_files=("lyra", "manual", "ppt
     start_time = parse_time(start_time)
     end_time = parse_time(end_time)
     # Check combine_files contains correct inputs
-    if not all(suffix in ["lyra", "manual", "ppt", "science"]
-               for suffix in combine_files):
-        raise ValueError("Elements in combine_files must be strings equalling "
-                         "'lyra', 'manual', 'ppt', or 'science'.")
+    if not all(
+        suffix in ["lyra", "manual", "ppt", "science"] for suffix in combine_files
+    ):
+        raise ValueError(
+            "Elements in combine_files must be strings equalling "
+            "'lyra', 'manual', 'ppt', or 'science'."
+        )
     # Remove any duplicates from combine_files input
     combine_files = list(set(combine_files))
     combine_files.sort()
     # Convert input times to UNIX timestamp format since this is the
     # time format in the annotation files
-    start_time_uts = (start_time - Time('1970-1-1')).sec
-    end_time_uts = (end_time - Time('1970-1-1')).sec
+    start_time_uts = (start_time - Time("1970-1-1")).sec
+    end_time_uts = (end_time - Time("1970-1-1")).sec
 
     # Define numpy record array which will hold the information from
     # the annotation file.
-    lytaf = np.empty((0,), dtype=[("insertion_time", object),
-                                  ("begin_time", object),
-                                  ("reference_time", object),
-                                  ("end_time", object),
-                                  ("event_type", object),
-                                  ("event_definition", object)])
+    lytaf = np.empty(
+        (0,),
+        dtype=[
+            ("insertion_time", object),
+            ("begin_time", object),
+            ("reference_time", object),
+            ("end_time", object),
+            ("event_type", object),
+            ("event_definition", object),
+        ],
+    )
     # Access annotation files
     for suffix in combine_files:
         # Check database files are present
@@ -375,12 +403,12 @@ def get_lytaf_events(start_time, end_time, combine_files=("lyra", "manual", "ppt
         # user.  If not, download newest version.
         # First get start time of first event and end time of last
         # event in lytaf.
-        cursor.execute("select begin_time from event order by begin_time asc "
-                       "limit 1;")
+        cursor.execute(
+            "select begin_time from event order by begin_time asc " "limit 1;"
+        )
         db_first_begin_time = cursor.fetchone()[0]
         db_first_begin_time = datetime.datetime.fromtimestamp(db_first_begin_time)
-        cursor.execute("select end_time from event order by end_time desc "
-                       "limit 1;")
+        cursor.execute("select end_time from event order by end_time desc " "limit 1;")
         db_last_end_time = cursor.fetchone()[0]
         db_last_end_time = datetime.datetime.fromtimestamp(db_last_end_time)
         # If lytaf does not include entire input time range...
@@ -390,17 +418,20 @@ def get_lytaf_events(start_time, end_time, combine_files=("lyra", "manual", "ppt
                 cursor.close()
                 connection.close()
                 # ...Download latest lytaf file...
-                lytaf_path = cache.download(urljoin(LYTAF_REMOTE_PATH, dbname),
-                                            redownload=True)
+                lytaf_path = cache.download(
+                    urljoin(LYTAF_REMOTE_PATH, dbname), redownload=True
+                )
                 # ...and open new version of lytaf database.
                 connection = sqlite3.connect(str(lytaf_path))
                 cursor = connection.cursor()
         # Select and extract the data from event table within file within
         # given time range
-        cursor.execute("select insertion_time, begin_time, reference_time, "
-                       "end_time, eventType_id from event where end_time >= "
-                       "{} and begin_time <= "
-                       "{}".format(start_time_uts, end_time_uts))
+        cursor.execute(
+            "select insertion_time, begin_time, reference_time, "
+            "end_time, eventType_id from event where end_time >= "
+            "{} and begin_time <= "
+            "{}".format(start_time_uts, end_time_uts)
+        )
         event_rows = cursor.fetchall()
         # Select and extract the event types from eventType table
         cursor.row_factory = sqlite3.Row
@@ -416,17 +447,32 @@ def get_lytaf_events(start_time, end_time, combine_files=("lyra", "manual", "ppt
         # Enter desired information into the lytaf numpy record array
         for event_row in event_rows:
             id_index = eventType_id.index(event_row[4])
-            lytaf = np.append(lytaf,
-                              np.array((Time(datetime.datetime.utcfromtimestamp(event_row[0]),
-                                             format='datetime'),
-                                        Time(datetime.datetime.utcfromtimestamp(event_row[1]),
-                                             format='datetime'),
-                                        Time(datetime.datetime.utcfromtimestamp(event_row[2]),
-                                             format='datetime'),
-                                        Time(datetime.datetime.utcfromtimestamp(event_row[3]),
-                                             format='datetime'),
-                                        eventType_type[id_index],
-                                        eventType_definition[id_index]), dtype=lytaf.dtype))
+            lytaf = np.append(
+                lytaf,
+                np.array(
+                    (
+                        Time(
+                            datetime.datetime.utcfromtimestamp(event_row[0]),
+                            format="datetime",
+                        ),
+                        Time(
+                            datetime.datetime.utcfromtimestamp(event_row[1]),
+                            format="datetime",
+                        ),
+                        Time(
+                            datetime.datetime.utcfromtimestamp(event_row[2]),
+                            format="datetime",
+                        ),
+                        Time(
+                            datetime.datetime.utcfromtimestamp(event_row[3]),
+                            format="datetime",
+                        ),
+                        eventType_type[id_index],
+                        eventType_definition[id_index],
+                    ),
+                    dtype=lytaf.dtype,
+                ),
+            )
         # Close file
         cursor.close()
         connection.close()
@@ -436,8 +482,8 @@ def get_lytaf_events(start_time, end_time, combine_files=("lyra", "manual", "ppt
     # If csvfile kwarg is set, write out lytaf to csv file
     if csvfile:
         # Open and write data to csv file.
-        with open(csvfile, 'w') as openfile:
-            csvwriter = csv.writer(openfile, delimiter=';')
+        with open(csvfile, "w") as openfile:
+            csvwriter = csv.writer(openfile, delimiter=";")
             # Write header.
             csvwriter.writerow(lytaf.dtype.names)
             # Write data.
@@ -485,14 +531,14 @@ def get_lytaf_event_types(print_event_types=True):
         event_types = cursor.fetchall()
         all_event_types.append(event_types)
         if print_event_types:
-            print("----------------\n{} database\n----------------"
-                  .format(suffix))
+            print(f"----------------\n{suffix} database\n----------------")
             for event_type in event_types:
                 print(str(event_type[0]))
             print(" ")
     # Unpack event types in all_event_types into single list
-    all_event_types = [event_type[0] for event_types in all_event_types
-                       for event_type in event_types]
+    all_event_types = [
+        event_type[0] for event_types in all_event_types for event_type in event_types
+    ]
     return all_event_types
 
 
@@ -527,8 +573,8 @@ def split_series_using_lytaf(timearray, data, lytaf):
     # scan through each entry retrieved from the LYTAF database
     for j in range(0, el):
         # want to mark all times with events as bad in the mask, i.e. = 0
-        start_dt = lytaf['begin_time'][j]
-        end_dt = lytaf['end_time'][j]
+        start_dt = lytaf["begin_time"][j]
+        end_dt = lytaf["end_time"][j]
 
         # find the start and end indices for each event
         start_ind = np.searchsorted(time_array, start_dt)
@@ -538,14 +584,15 @@ def split_series_using_lytaf(timearray, data, lytaf):
         mask[start_ind:end_ind] = 0
 
     diffmask = np.diff(mask)
-    tmp_discontinuity = np.where(diffmask != 0.)
+    tmp_discontinuity = np.where(diffmask != 0.0)
     # disc contains the indices of mask where there are discontinuities
     disc = tmp_discontinuity[0]
 
     if len(disc) == 0:
-        print('No events found within time series interval. '
-              'Returning original series.')
-        return [{'subtimes': time_array, 'subdata': data}]
+        print(
+            "No events found within time series interval. " "Returning original series."
+        )
+        return [{"subtimes": time_array, "subdata": data}]
 
     # -1 in diffmask means went from good data to bad
     # +1 means went from bad data to good
@@ -563,16 +610,16 @@ def split_series_using_lytaf(timearray, data, lytaf):
     # now extract the good data regions and ignore the bad ones
     for h in range(0, limit, 2):
 
-        if h == limit-1:
+        if h == limit - 1:
             # can't index h+1 here. Go to end of series
-            subtimes = time_array[disc[h]:-1]
-            subdata = data[disc[h]:-1]
-            subseries = {'subtimes': subtimes, 'subdata': subdata}
+            subtimes = time_array[disc[h] : -1]
+            subdata = data[disc[h] : -1]
+            subseries = {"subtimes": subtimes, "subdata": subdata}
             split_series.append(subseries)
         else:
-            subtimes = time_array[disc[h]:disc[h+1]]
-            subdata = data[disc[h]:disc[h+1]]
-            subseries = {'subtimes': subtimes, 'subdata': subdata}
+            subtimes = time_array[disc[h] : disc[h + 1]]
+            subdata = data[disc[h] : disc[h + 1]]
+            subseries = {"subtimes": subtimes, "subdata": subdata}
             split_series.append(subseries)
 
     return split_series
@@ -585,27 +632,27 @@ def _lytaf_event2string(integers):
 
     for i in integers:
         if i == 1:
-            out.append('LAR')
+            out.append("LAR")
         if i == 2:
-            out.append('N/A')
+            out.append("N/A")
         if i == 3:
-            out.append('UV occult.')
+            out.append("UV occult.")
         if i == 4:
-            out.append('Vis. occult.')
+            out.append("Vis. occult.")
         if i == 5:
-            out.append('Offpoint')
+            out.append("Offpoint")
         if i == 6:
-            out.append('SAA')
+            out.append("SAA")
         if i == 7:
-            out.append('Auroral zone')
+            out.append("Auroral zone")
         if i == 8:
-            out.append('Moon in LYRA')
+            out.append("Moon in LYRA")
         if i == 9:
-            out.append('Moon in SWAP')
+            out.append("Moon in SWAP")
         if i == 10:
-            out.append('Venus in LYRA')
+            out.append("Venus in LYRA")
         if i == 11:
-            out.append('Venus in SWAP')
+            out.append("Venus in SWAP")
 
     return out
 
@@ -648,16 +695,17 @@ def _prep_columns(time, channels=None, filecolumns=None):
         else:
             ncol = 1
         if len(filecolumns) != ncol:
-            raise ValueError("Number of elements in filecolumns must be "
-                             "equal to the number of input data arrays, "
-                             "i.e. time + elements in channels.")
+            raise ValueError(
+                "Number of elements in filecolumns must be "
+                "equal to the number of input data arrays, "
+                "i.e. time + elements in channels."
+            )
     # If filenames not given, create a list of columns names of the
     # form: ["time", "channel0", "channel1",...,"channelN"] where N
     # is the number of arrays in channels (assuming 0-indexed counting).
     else:
         if channels:
-            filecolumns = [f"channel{fluxnum}"
-                           for fluxnum in range(len(channels))]
+            filecolumns = [f"channel{fluxnum}" for fluxnum in range(len(channels))]
             filecolumns.insert(0, "time")
         else:
             filecolumns = ["time"]
